@@ -56,7 +56,7 @@ public:
     static const int MaxViewCount;
 
     ViewMainPage(QWidget* parent, SlideShow*, KActionCollection*, GvCore*);
-    ~ViewMainPage();
+    ~ViewMainPage() Q_DECL_OVERRIDE;
 
     ThumbnailBarView* thumbnailBar() const;
 
@@ -124,6 +124,10 @@ Q_SIGNALS:
 
     void nextImageRequested();
 
+    void openUrlRequested(const QUrl&);
+
+    void openDirUrlRequested(const QUrl&);
+
     void toggleFullScreenRequested();
 
     void goToBrowseModeRequested();
@@ -145,6 +149,8 @@ private Q_SLOTS:
     void trashView(DocumentView*);
     void deselectView(DocumentView*);
 
+    void slotDirModelItemsAddedOrRemoved();
+
 protected:
     bool eventFilter(QObject* watched, QEvent* event) Q_DECL_OVERRIDE;
 
