@@ -19,7 +19,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 
 */
 // Self
-#include "documentviewcontainer.moc"
+#include "documentviewcontainer.h"
 
 // Local
 #include <lib/documentview/documentview.h>
@@ -28,24 +28,20 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include <lib/gwenviewconfig.h>
 
 // KDE
-#include <KDebug>
-#include <KUrl>
 
 // Qt
-#include <QEvent>
 #include <QGLWidget>
 #include <QGraphicsScene>
 #include <QPropertyAnimation>
 #include <QTimer>
-
-// libc
-#include <qmath.h>
+#include <QDebug>
+#include <QtMath>
 
 namespace Gwenview
 {
 
 typedef QSet<DocumentView*> DocumentViewSet;
-typedef QHash<KUrl, DocumentView::Setup> SetupForUrl;
+typedef QHash<QUrl, DocumentView::Setup> SetupForUrl;
 
 struct DocumentViewContainerPrivate
 {
@@ -96,7 +92,7 @@ DocumentViewContainer::DocumentViewContainer(QWidget* parent)
         if (glWidget->isValid()) {
             setViewport(glWidget);
         } else {
-            kWarning() << "Failed to initialize OpenGL support!";
+            qWarning() << "Failed to initialize OpenGL support!";
             delete glWidget;
         }
     }
@@ -110,9 +106,9 @@ DocumentViewContainer::DocumentViewContainer(QWidget* parent)
     d->mLayoutUpdateTimer = new QTimer(this);
     d->mLayoutUpdateTimer->setInterval(0);
     d->mLayoutUpdateTimer->setSingleShot(true);
-    connect(d->mLayoutUpdateTimer, SIGNAL(timeout()), SLOT(updateLayout()));
+    connect(d->mLayoutUpdateTimer, &QTimer::timeout, this, &DocumentViewContainer::updateLayout);
 
-    connect(GwenviewConfig::self(), SIGNAL(configChanged()), SLOT(slotConfigChanged()));
+    connect(GwenviewConfig::self(), &GwenviewConfig::configChanged, this, &DocumentViewContainer::slotConfigChanged);
 }
 
 DocumentViewContainer::~DocumentViewContainer()
@@ -123,10 +119,10 @@ DocumentViewContainer::~DocumentViewContainer()
 DocumentView* DocumentViewContainer::createView()
 {
     DocumentView* view = new DocumentView(d->mScene);
+    view->setPalette(palette());
     d->mAddedViews << view;
     view->show();
-    connect(view, SIGNAL(fadeInFinished(DocumentView*)),
-            SLOT(slotFadeInFinished(DocumentView*)));
+    connect(view, &DocumentView::fadeInFinished, this, &DocumentViewContainer::slotFadeInFinished);
     d->scheduleLayoutUpdate();
     return view;
 }
@@ -139,7 +135,7 @@ void DocumentViewContainer::deleteView(DocumentView* view)
     d->removeFromSet(view, &d->mAddedViews);
 }
 
-DocumentView::Setup DocumentViewContainer::savedSetup(const KUrl& url) const
+DocumentView::Setup DocumentViewContainer::savedSetup(const QUrl& url) const
 {
     return d->mSetupForUrl.value(url);
 }
@@ -190,11 +186,10 @@ void DocumentViewContainer::updateLayout()
         DocumentView* newView = *d->mAddedViews.begin();
 
         newView->setGeometry(rect());
-        newView->setEraseBorders(true);
         QPropertyAnimation* anim = newView->fadeIn();
 
         oldView->setZValue(-1);
-        connect(anim, SIGNAL(finished()), oldView, SLOT(hideAndDeleteLater()));
+        connect(anim, &QPropertyAnimation::finished, oldView, &DocumentView::hideAndDeleteLater);
         d->mRemovedViews.clear();
 
         return;
@@ -261,7 +256,7 @@ void DocumentViewContainer::updateLayout()
             } else {
                 // Not animated, set final geometry and opacity now
                 view->setGeometry(rect);
-                view->setOpacity(1);
+                view->setGraphicsEffectOpacity(1);
             }
 
             ++col;
@@ -305,7 +300,6 @@ void DocumentViewContainer::slotFadeInFinished(DocumentView* view)
     }
     d->mAddedViews.remove(view);
     d->mViews.insert(view);
-    view->setEraseBorders(false);
 }
 
 void DocumentViewContainer::slotConfigChanged()
@@ -319,7 +313,7 @@ void DocumentViewContainer::slotConfigChanged()
 
 void DocumentViewContainer::showMessageWidget(QGraphicsWidget* widget, Qt::Alignment align)
 {
-    DocumentView* view = 0;
+    DocumentView* view = nullptr;
     if (d->mViews.isEmpty()) {
         GV_RETURN_IF_FAIL(!d->mAddedViews.isEmpty());
         view = *d->mAddedViews.begin();
@@ -336,4 +330,12 @@ void DocumentViewContainer::showMessageWidget(QGraphicsWidget* widget, Qt::Align
     widget->setZValue(1);
 }
 
+void DocumentViewContainer::applyPalette(const QPalette& palette)
+{
+    setPalette(palette);
+    for (DocumentView* view : d->mViews | d->mAddedViews) {
+        view->setPalette(palette);
+    }
+}
+
 } // namespace
