@@ -36,11 +36,11 @@ class ItemEditor : public KLineEdit
 {
     Q_OBJECT
 public:
-    ItemEditor(QWidget* parent = 0);
-    ~ItemEditor();
+    explicit ItemEditor(QWidget* parent = nullptr);
+    ~ItemEditor() Q_DECL_OVERRIDE;
 
 protected:
-    virtual void showEvent(QShowEvent*);
+    void showEvent(QShowEvent*) Q_DECL_OVERRIDE;
 
 private Q_SLOTS:
     void resizeToContents();
